@@ -31,6 +31,7 @@ from airflow.providers.qubole.hooks.qubole import (
 )
 
 if TYPE_CHECKING:
+    from airflow.models.taskinstance import TaskInstanceKey
     from airflow.utils.context import Context
 
 
@@ -39,7 +40,13 @@ class QDSLink(BaseOperatorLink):
 
     name = 'Go to QDS'
 
-    def get_link(self, operator: BaseOperator, dttm: datetime) -> str:
+    def get_link(
+        self,
+        operator: BaseOperator,
+        dttm: Optional[datetime] = None,
+        *,
+        ti_key: Optional["TaskInstanceKey"] = None,
+    ) -> str:
         """
         Get link to qubole command result page.
 
@@ -55,9 +62,13 @@ class QDSLink(BaseOperatorLink):
             host = re.sub(r'api$', 'v2/analyze?command_id=', conn.host)
         else:
             host = 'https://api.qubole.com/v2/analyze?command_id='
-        qds_command_id = XCom.get_one(
-            key='qbol_cmd_id', dag_id=operator.dag.dag_id, task_id=operator.task_id, execution_date=dttm
-        )
+        if ti_key is not None:
+            qds_command_id = XCom.get_value(key='qbol_cmd_id', ti_key=ti_key)
+        else:
+            assert dttm
+            qds_command_id = XCom.get_one(
+                key='qbol_cmd_id', dag_id=operator.dag_id, task_id=operator.task_id, execution_date=dttm
+            )
         url = host + str(qds_command_id) if qds_command_id else ''
         return url
 
@@ -164,8 +175,8 @@ class QuboleOperator(BaseOperator):
         jupytercmd:
             :path: Path including name of the Jupyter notebook to be run with extension.
             :arguments: Valid JSON to be sent to the notebook. Specify the parameters in notebooks and pass
-                the parameter value using the JSON format. key is the parameter’s name and value is
-                the parameter’s value. Supported types in parameters are string, integer, float and boolean.
+                the parameter value using the JSON format. key is the parameter's name and value is
+                the parameter's value. Supported types in parameters are string, integer, float and boolean.
 
     .. note:
 
